@@ -25,5 +25,7 @@ class GitbucketControl:
         self.systemd.stop()
         self.systemd.disable()
 
-    def status(self):
-        return self.systemd.is_active()
\ No newline at end of file
+    def url(self):
+        self.systemd.check_active()
+        info = self.insider.service_info(SERVICE_NAME)
+        return '{0}://{1}:{2}/{3}'.format(info.service.protocol, info.external_host, info.external_port, info.service.url)
\ No newline at end of file
